(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs/operators'), require('rxjs'), require('@wizdm/stripe'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('@wizdm/stripe/elements', ['exports', '@angular/core', 'rxjs/operators', 'rxjs', '@wizdm/stripe', '@angular/common'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global.wizdm = global.wizdm || {}, global.wizdm.stripe = global.wizdm.stripe || {}, global.wizdm.stripe.elements = {}), global.ng.core, global.rxjs.operators, global.rxjs, global.wizdm.stripe, global.ng.common));
}(this, (function (exports, core, operators, rxjs, stripe, common) { 'use strict';

    /** StripeElementsModule configuration token */
    var STRIPE_ELEMENTS_OPTIONS = new core.InjectionToken('wizdm.stripe.elements.options');
    /** Relays the Elements funcitons enabling dynamic locale */
    var StripeElementsDirective = /** @class */ (function () {
        function StripeElementsDirective(stripe, options) {
            var _this = this;
            this.locale$ = new rxjs.BehaviorSubject(undefined);
            this.elements$ = stripe.stripe$.pipe(operators.switchMap(function (stripe) { return _this.locale$.pipe(operators.map(function (locale) { return stripe.elements(Object.assign(Object.assign({}, options), { locale: locale })); })); }), operators.shareReplay(1));
        }
        Object.defineProperty(StripeElementsDirective.prototype, "StripeElements", {
            /** The Elements locale to use. The locale is automatically detected when undefined */
            set: function (locale) {
                this.locale$.next(locale);
            },
            enumerable: false,
            configurable: true
        });
        /** Creates a Stripe Element of the given type using the given locale and options */
        StripeElementsDirective.prototype.create = function (elementType, options) {
            return this.elements$.pipe(operators.map(function (elements) { return elements.create(elementType, options); }));
        };
        return StripeElementsDirective;
    }());
    StripeElementsDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[StripeElements]',
                    exportAs: 'StripeElements'
                },] }
    ];
    /** @nocollapse */
    StripeElementsDirective.ctorParameters = function () { return [
        { type: stripe.StripeService },
        { type: undefined, decorators: [{ type: core.Optional }, { type: core.Inject, args: [STRIPE_ELEMENTS_OPTIONS,] }] }
    ]; };
    StripeElementsDirective.propDecorators = {
        StripeElements: [{ type: core.Input }]
    };

    /** @dynamic
     * Base element class turning a StripeElement into an Angular component with common features
     * To be used as the base class for all the Stripe related specific components: StripeCard...
     */
    var StripeElementDirective = /** @class */ (function () {
        function StripeElementDirective(elementType, elements, ref) {
            var _this = this;
            this.init$ = new rxjs.Subject();
            this._options = {};
            /** Emits on value changes */
            this.valueChange = new core.EventEmitter();
            /** Emits when fully loaded */
            this.readyChange = new core.EventEmitter(true);
            /** Emits when focused */
            this.focusChange = new core.EventEmitter();
            /** Emits when blurred */
            this.blurChange = new core.EventEmitter();
            /** Emits when escape is pressed */
            this.escapeChange = new core.EventEmitter();
            // Ensures the element is used within the StripeElement container
            if (!elements) {
                throw new Error("\n      You're attempting to use a Stripe Element out of a proper StripeElements container.\n      Make sure to wrap all the controls within a wm-stripe-elements directive.\n    ");
            }
            // Creates the StripeElement observable
            this.element$ = this.init$.pipe(operators.take(1), operators.switchMap(function (options) { return elements.create(elementType, options).pipe(operators.tap(function (elm) {
                // Disposes of the previous element instance, if any
                _this._instance && _this._instance.destroy();
                // Hooks on the common element's events
                elm.on('ready', function () { _this.readyChange.emit(_this._ready = true); });
                elm.on('focus', function () { _this._focused = true; _this.focusChange.emit(); });
                elm.on('blur', function () { _this._focused = false; _this.blurChange.emit(); });
                // Mounts the element on the DOM
                elm.mount(ref.nativeElement);
                // Keeps track of the current StripeElement instance
                return _this._instance = elm;
            })); }), operators.shareReplay(1));
            // Subscribes to the element's observable waiting for the init$ to emit
            this.sub = this.element$.subscribe();
        }
        Object.defineProperty(StripeElementDirective.prototype, "instance", {
            /** The StripeElement instance */
            get: function () { return this._instance; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "value", {
            /** The latest change value */
            get: function () { return this._value; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "empty", {
            /** True whenever the element is empty */
            get: function () { return !this._value || this._value.empty; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "complete", {
            /** True whenever the element is complete and valid */
            get: function () { return !!this._value && this._value.complete; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "error", {
            /** The StripeError or null */
            get: function () { return !!this._value && this._value.error || null; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "ready", {
            /** True whenever the element is fully loaded */
            get: function () { return !!this._ready; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "focused", {
            /** True whenever the element is focused */
            get: function () { return !!this._focused; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "disabled", {
            /** True whenever the element is disabled */
            get: function () { return false; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "options", {
            /** Returns the current options object */
            get: function () { return this._options || (this._options = {}); },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "classes", {
            /** Returns the current option classes object, if any */
            get: function () { return this._options.classes || (this._options.classes = {}); },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "style", {
            /** Returns the current option style object, if any */
            get: function () { return this._options.style || (this._options.style = {}); },
            enumerable: false,
            configurable: true
        });
        /** Initialize the StripeElement with the given options */
        StripeElementDirective.prototype.init = function (options) {
            // Pushes the initial element options object triggering the element$ Observable to emit
            this.init$.next(options);
        };
        /** Forwards the given call to the StripeElement */
        StripeElementDirective.prototype.forward = function (fn) {
            // Short circuits with the current instance, if any
            if (this.instance) {
                return fn(this.instance);
            }
            // Resolves the observable to get the latest instance otherwise
            this.element$.pipe(operators.take(1)).subscribe(function (instance) { return fn(instance); });
        };
        /** Disables the element whenever possible. Ovverrides this default implementation to forward the status down the Element */
        StripeElementDirective.prototype.disable = function (_) { };
        /** Focuses the element */
        StripeElementDirective.prototype.focus = function () { this.forward(function (instance) { return instance.focus(); }); };
        /** Blurs the element */
        StripeElementDirective.prototype.blur = function () { this.forward(function (instance) { return instance.blur(); }); };
        /** Clears the element */
        StripeElementDirective.prototype.clear = function () { this.forward(function (instance) { return instance.clear(); }); };
        Object.defineProperty(StripeElementDirective.prototype, "classBase", {
            /** Class applied to the StripeElement's container. Defaults to StripeElement */
            set: function (value) { this.classes.base = value; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "classComplete", {
            /** The class name to apply when the Element is complete. Defaults to StripeElement--complete */
            set: function (value) { this.classes.complete = value; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "classEmpty", {
            /** The class name to apply when the Element is empty. Defaults to StripeElement--empty */
            set: function (value) { this.classes.empty = value; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "classFocus", {
            /** The class name to apply when the Element has focus. Defaults to StripeElement--focus */
            set: function (value) { this.classes.focus = value; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StripeElementDirective.prototype, "classInvalid", {
            /** The class name to apply when the Element is invalid. Defaults to StripeElement--invalid */
            set: function (value) { this.classes.invalid = value; },
            enumerable: false,
            configurable: true
        });
        // Disposes of the element
        StripeElementDirective.prototype.ngOnDestroy = function () {
            this.forward(function (instance) { return instance.destroy(); });
            this.sub.unsubscribe();
        };
        return StripeElementDirective;
    }());
    StripeElementDirective.decorators = [
        { type: core.Directive }
    ];
    /** @nocollapse */
    StripeElementDirective.ctorParameters = function () { return [
        { type: undefined },
        { type: StripeElementsDirective },
        { type: core.ElementRef }
    ]; };
    StripeElementDirective.propDecorators = {
        classBase: [{ type: core.Input }],
        classComplete: [{ type: core.Input }],
        classEmpty: [{ type: core.Input }],
        classFocus: [{ type: core.Input }],
        classInvalid: [{ type: core.Input }],
        valueChange: [{ type: core.Output, args: ['change',] }],
        readyChange: [{ type: core.Output, args: ['ready',] }],
        focusChange: [{ type: core.Output, args: ['focus',] }],
        blurChange: [{ type: core.Output, args: ['blur',] }],
        escapeChange: [{ type: core.Output, args: ['escape',] }]
    };
    function computeBaseStyle(el) {
        // Computes the element's base style to match the given HTML element
        var computed = window === null || window === void 0 ? void 0 : window.getComputedStyle(el);
        return {
            color: computed.color,
            fontFamily: computed.fontFamily,
            fontSize: computed.fontSize,
            fontStyle: computed.fontStyle,
            fontVariant: computed.fontVariant,
            fontWeight: computed.fontWeight,
            letterSpacing: computed.letterSpacing,
            textDecoration: computed.textDecoration,
            textShadow: computed.textShadow,
            textTransform: computed.textTransform
        };
    }

    /** @dynamic
     * Base class bridging the StripeElement with the Angular's form API implementing both a ControlValueAccessor
     * and a sync Validator enabling the use with FormControl
     */
    var StripeControlDirective = /** @class */ (function () {
        function StripeControlDirective(element) {
            this.element = element;
            this.sub = new rxjs.Subscription();
        }
        StripeControlDirective.prototype.ngOnDestroy = function () { this.sub.unsubscribe(); };
        /**
         * Called by the forms API to write to the view when programmatic changes from model to view are requested.
         * NOTE: Only clearing the control is allowed
         */
        StripeControlDirective.prototype.writeValue = function (value) {
            if (!value) {
                this.element.clear();
            }
        };
        /**
         * Function that is called by the forms API when the control status changes to or from 'DISABLED'.
         * Depending on the status, it enables or disables the appropriate DOM element.
         */
        StripeControlDirective.prototype.setDisabledState = function (disabled) {
            this.element.disable(disabled);
        };
        /**
         * Registers a callback function that is called when the control's value changes in the UI.
         * The value passed along the FormControl is the stripe Element instance to be used in the
         * payment_method object to setup or confirm the payment.
         */
        StripeControlDirective.prototype.registerOnChange = function (fn) {
            var _this = this;
            this.sub.add(this.element.valueChange.subscribe(function (value) { return fn(value.complete ? _this.element.instance : null); }));
        };
        /** Registers a callback function is called by the forms API on initialization to update the form model on blur. */
        StripeControlDirective.prototype.registerOnTouched = function (fn) {
            this.sub.add(this.element.blurChange.subscribe(function () { return fn(); }));
        };
        /** Performs synchronous validation against the provided control. */
        StripeControlDirective.prototype.validate = function (control) {
            var _a;
            // Whenever the element is complete...
            if (this.element.complete) {
                // Checks for errors
                var errorType = this.element.error && this.element.error.type;
                // Translates the StripeError into a ValidationError passing along the message
                return errorType ? (_a = {}, _a[errorType] = this.element.error.message, _a) : null;
            }
            return { required: true };
        };
        return StripeControlDirective;
    }());
    StripeControlDirective.decorators = [
        { type: core.Directive }
    ];
    /** @nocollapse */
    StripeControlDirective.ctorParameters = function () { return [
        { type: StripeElementDirective }
    ]; };

    var StripeElementsModule = /** @class */ (function () {
        function StripeElementsModule(platformId) {
            if (!common.isPlatformBrowser(platformId)) {
                throw new Error('StripeModule package supports Browsers only');
            }
        }
        StripeElementsModule.init = function (options) {
            return {
                ngModule: StripeElementsModule,
                /** Provides the global StripeElementsOptions object */
                providers: [{ provide: STRIPE_ELEMENTS_OPTIONS, useValue: options }]
            };
        };
        return StripeElementsModule;
    }());
    StripeElementsModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [StripeElementsDirective],
                    exports: [StripeElementsDirective]
                },] }
    ];
    /** @nocollapse */
    StripeElementsModule.ctorParameters = function () { return [
        { type: Object, decorators: [{ type: core.Inject, args: [core.PLATFORM_ID,] }] }
    ]; };

    /**
     * Generated bundle index. Do not edit.
     */

    exports.STRIPE_ELEMENTS_OPTIONS = STRIPE_ELEMENTS_OPTIONS;
    exports.StripeControlDirective = StripeControlDirective;
    exports.StripeElementDirective = StripeElementDirective;
    exports.StripeElementsDirective = StripeElementsDirective;
    exports.StripeElementsModule = StripeElementsModule;
    exports.computeBaseStyle = computeBaseStyle;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=wizdm-stripe-elements.umd.js.map
