import { AbstractControl, ControlValueAccessor, Validator, ValidationErrors } from '@angular/forms';
import { StripeElementDirective } from './element.directive';
import { OnDestroy } from '@angular/core';
import type { StripeElementType } from '@stripe/stripe-js';
/** @dynamic
 * Base class bridging the StripeElement with the Angular's form API implementing both a ControlValueAccessor
 * and a sync Validator enabling the use with FormControl
 */
export declare class StripeControlDirective<T extends Exclude<StripeElementType, 'paymentRequestButton'>> implements ControlValueAccessor, Validator, OnDestroy {
    readonly element: StripeElementDirective<T>;
    private sub;
    constructor(element: StripeElementDirective<T>);
    ngOnDestroy(): void;
    /**
     * Called by the forms API to write to the view when programmatic changes from model to view are requested.
     * NOTE: Only clearing the control is allowed
     */
    writeValue(value: any): void;
    /**
     * Function that is called by the forms API when the control status changes to or from 'DISABLED'.
     * Depending on the status, it enables or disables the appropriate DOM element.
     */
    setDisabledState(disabled: boolean): void;
    /**
     * Registers a callback function that is called when the control's value changes in the UI.
     * The value passed along the FormControl is the stripe Element instance to be used in the
     * payment_method object to setup or confirm the payment.
     */
    registerOnChange(fn: (_: any) => void): void;
    /** Registers a callback function is called by the forms API on initialization to update the form model on blur. */
    registerOnTouched(fn: () => void): void;
    /** Performs synchronous validation against the provided control. */
    validate(control: AbstractControl): ValidationErrors | null;
}
