import { OnDestroy, ElementRef, EventEmitter } from '@angular/core';
import { StripeElementsDirective } from './elements.directive';
import type { StripeError, StripeElementType, StripeElementCSSProperties } from '@stripe/stripe-js';
import type { StripeElement, StripeElementOptions, StripeElementChangeEvent } from './generic-types';
/** @dynamic
 * Base element class turning a StripeElement into an Angular component with common features
 * To be used as the base class for all the Stripe related specific components: StripeCard...
 */
export declare class StripeElementDirective<T extends StripeElementType> implements OnDestroy {
    private element$;
    private init$;
    private _options;
    private sub;
    /** The StripeElement instance */
    get instance(): StripeElement<T>;
    private _instance;
    /** The latest change value */
    get value(): StripeElementChangeEvent<T>;
    protected _value: StripeElementChangeEvent<T>;
    /** True whenever the element is empty */
    get empty(): boolean;
    /** True whenever the element is complete and valid */
    get complete(): boolean;
    /** The StripeError or null */
    get error(): StripeError | null;
    /** True whenever the element is fully loaded */
    get ready(): boolean;
    private _ready;
    /** True whenever the element is focused */
    get focused(): boolean;
    private _focused;
    /** True whenever the element is disabled */
    get disabled(): boolean;
    constructor(elementType: T, elements: StripeElementsDirective, ref: ElementRef<HTMLElement>);
    /** Returns the current options object */
    protected get options(): StripeElementOptions<T>;
    /** Returns the current option classes object, if any */
    protected get classes(): StripeElementOptions<T>['classes'];
    /** Returns the current option style object, if any */
    protected get style(): StripeElementOptions<T>['style'];
    /** Initialize the StripeElement with the given options */
    protected init(options: StripeElementOptions<T>): void;
    /** Forwards the given call to the StripeElement */
    protected forward(fn: (elm: StripeElement<T>) => void): void;
    /** Disables the element whenever possible. Ovverrides this default implementation to forward the status down the Element */
    disable(_: boolean): void;
    /** Focuses the element */
    focus(): void;
    /** Blurs the element */
    blur(): void;
    /** Clears the element */
    clear(): void;
    /** Class applied to the StripeElement's container. Defaults to StripeElement */
    set classBase(value: string);
    /** The class name to apply when the Element is complete. Defaults to StripeElement--complete */
    set classComplete(value: string);
    /** The class name to apply when the Element is empty. Defaults to StripeElement--empty */
    set classEmpty(value: string);
    /** The class name to apply when the Element has focus. Defaults to StripeElement--focus */
    set classFocus(value: string);
    /** The class name to apply when the Element is invalid. Defaults to StripeElement--invalid */
    set classInvalid(value: string);
    /** Emits on value changes */
    valueChange: EventEmitter<StripeElementChangeEvent<T>>;
    /** Emits when fully loaded */
    readyChange: EventEmitter<boolean>;
    /** Emits when focused */
    focusChange: EventEmitter<void>;
    /** Emits when blurred */
    blurChange: EventEmitter<void>;
    /** Emits when escape is pressed */
    escapeChange: EventEmitter<void>;
    ngOnDestroy(): void;
}
export declare function computeBaseStyle(el: HTMLElement): StripeElementCSSProperties;
