import { StripeElementsDirective, StripeElementDirective, StripeControlDirective } from '@wizdm/stripe/elements';
import { OnInit, OnChanges, ElementRef } from '@angular/core';
import type { StripeFpxBankElementOptions, StripeElementStyleVariant } from '@stripe/stripe-js';
/** Bridge with the Angular's form API */
export declare class StripeFpxBankControl extends StripeControlDirective<'fpxBank'> {
}
/** Stripe fpxBank Element
 * @see https://stripe.com/docs/payments/fpx
 */
export declare class StripeFpxBank extends StripeElementDirective<'fpxBank'> implements OnInit, OnChanges {
    private ref;
    constructor(elements: StripeElementsDirective, ref: ElementRef<HTMLElement>);
    get disabled(): boolean;
    disable(disabled: boolean): void;
    ngOnInit(): void;
    ngOnChanges(): void;
    /** Element's custom base style.
     * @see https://stripe.com/docs/js/appendix/style
     * Setting this input value to 'auto' enables the automatic detection of the element's style */
    set styleBase(value: StripeElementStyleVariant | 'auto');
    /** Element's custom complete style.
     * @see https://stripe.com/docs/js/appendix/style */
    set styleComplete(value: StripeElementStyleVariant);
    /** Element's custom empty style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleEmpty(value: StripeElementStyleVariant): void;
    /** Element's custom invalid style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleInvalid(value: StripeElementStyleVariant): void;
    /** Account Holder Type */
    set accountHolderType(value: StripeFpxBankElementOptions['accountHolderType']);
    /**
     * A pre-filled value for the Element. Can be one of the banks listed in the
     * @see https://stripe.com/docs/payments/fpx/accept-a-payment#bank-reference
     * @example 'affin_bank'
     */
    set fpxValue(value: string);
    /** Disables the element */
    set disabled(value: boolean);
}
