import { StripeControlDirective, StripeElementDirective, computeBaseStyle, StripeElementsDirective } from '@wizdm/stripe/elements';
import { Directive, forwardRef, Component, Optional, ElementRef, Input, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, NG_VALIDATORS } from '@angular/forms';
import { coerceBooleanProperty } from '@angular/cdk/coercion';

/** Bridge with the Angular's form API */
class StripeCardControl extends StripeControlDirective {
}
StripeCardControl.decorators = [
    { type: Directive, args: [{
                selector: 'wm-stripe-card[ngModel], wm-stripe-card[formControl], wm-stripe-card[formControlName]',
                providers: [
                    { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => StripeCardControl), multi: true },
                    { provide: NG_VALIDATORS, useExisting: forwardRef(() => StripeCardControl), multi: true }
                ]
            },] }
];
/** Stripe Card Element for Angular */
class StripeCard extends StripeElementDirective {
    constructor(elements, ref) {
        super('card', elements, ref);
        this.ref = ref;
        // Hooks on CardElement specific events
        this.forward(elm => {
            elm.on('change', value => this.valueChange.emit(this._value = value));
            elm.on('escape', () => this.escapeChange.emit());
        });
    }
    // Overrides the disabled getter to effectively return the status
    get disabled() { return !!this.options.disabled; }
    // Ovverrides the disable function forwarding the call to the StripeElement 
    disable(disabled) {
        this.disabled = disabled;
        this.forward(elm => elm.update(this.options));
    }
    // Initializes the element
    ngOnInit() { this.init(this.options); }
    // Updates the element on input changes
    ngOnChanges() { this.forward(elm => elm.update(this.options)); }
    /** Element's custom base style.
     * @see https://stripe.com/docs/js/appendix/style
     * Setting this input value to 'auto' enables the automatic detection of the element's style */
    set styleBase(value) {
        this.style.base = (value === 'auto') ? computeBaseStyle(this.ref.nativeElement) : value;
    }
    /** Element's custom complete style.
     * @see https://stripe.com/docs/js/appendix/style */
    set styleComplete(value) {
        this.style.complete = value;
    }
    /** Element's custom empty style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleEmpty(value) {
        this.style.empty = value;
    }
    /** Element's custom invalid style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleInvalid(value) {
        this.style.invalid = value;
    }
    /** Hides the card icon */
    set hideIcon(value) {
        this.options.hideIcon = coerceBooleanProperty(value);
    }
    /** Hides the postal code */
    set hidePostalCode(value) {
        this.options.hidePostalCode = coerceBooleanProperty(value);
    }
    /** Selects the icon style */
    set iconStyle(value) {
        this.options.iconStyle = value;
    }
    /** Disables the element */
    set disabled(value) {
        this.options.disabled = coerceBooleanProperty(value);
    }
}
StripeCard.decorators = [
    { type: Component, args: [{
                selector: 'wm-stripe-card',
                template: '',
                providers: [
                    { provide: StripeElementDirective, useExisting: forwardRef(() => StripeCard) }
                ]
            },] }
];
/** @nocollapse */
StripeCard.ctorParameters = () => [
    { type: StripeElementsDirective, decorators: [{ type: Optional }] },
    { type: ElementRef }
];
StripeCard.propDecorators = {
    styleBase: [{ type: Input }],
    styleComplete: [{ type: Input }],
    styleEmpty: [{ type: Input }],
    styleInvalid: [{ type: Input }],
    hideIcon: [{ type: Input }],
    hidePostalCode: [{ type: Input }],
    iconStyle: [{ type: Input }],
    disabled: [{ type: Input }]
};

/** Bridge with the Angular's form API */
class StripeCardExpiryControl extends StripeControlDirective {
}
StripeCardExpiryControl.decorators = [
    { type: Directive, args: [{
                selector: 'wm-stripe-card-expiry[ngModel], wm-stripe-card-expiry[formControl], wm-stripe-card-expiry[formControlName]',
                providers: [
                    { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => StripeCardExpiryControl), multi: true },
                    { provide: NG_VALIDATORS, useExisting: forwardRef(() => StripeCardExpiryControl), multi: true }
                ]
            },] }
];
/** Stripe Card Exipation Date Element for Angular */
class StripeCardExpiry extends StripeElementDirective {
    constructor(elements, ref) {
        super('cardExpiry', elements, ref);
        this.ref = ref;
        // Hooks on CardElement specific events
        this.forward(elm => {
            elm.on('change', value => this.valueChange.emit(this._value = value));
            elm.on('escape', () => this.escapeChange.emit());
        });
    }
    // Overrides the disabled getter to effectively return the status
    get disabled() { return !!this.options.disabled; }
    // Ovverrides the disable function forwarding the call to the StripeElement 
    disable(disabled) {
        this.disabled = disabled;
        this.forward(elm => elm.update(this.options));
    }
    // Initializes the element
    ngOnInit() { this.init(this.options); }
    // Updates the element on input changes
    ngOnChanges() { this.forward(elm => elm.update(this.options)); }
    /** Element's custom base style.
     * @see https://stripe.com/docs/js/appendix/style
     * Setting this input value to 'auto' enables the automatic detection of the element's style */
    set styleBase(value) {
        this.style.base = (value === 'auto') ? computeBaseStyle(this.ref.nativeElement) : value;
    }
    /** Element's custom complete style.
     * @see https://stripe.com/docs/js/appendix/style */
    set styleComplete(value) {
        this.style.complete = value;
    }
    /** Element's custom empty style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleEmpty(value) {
        this.style.empty = value;
    }
    /** Element's custom invalid style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleInvalid(value) {
        this.style.invalid = value;
    }
    /** A placeholder text */
    set placeholder(value) {
        this.options.placeholder = value;
    }
    /** Disables the element */
    set disabled(value) {
        this.options.disabled = coerceBooleanProperty(value);
    }
}
StripeCardExpiry.decorators = [
    { type: Component, args: [{
                selector: 'wm-stripe-card-expiry',
                template: '',
                providers: [
                    { provide: StripeElementDirective, useExisting: forwardRef(() => StripeCardExpiry) }
                ]
            },] }
];
/** @nocollapse */
StripeCardExpiry.ctorParameters = () => [
    { type: StripeElementsDirective, decorators: [{ type: Optional }] },
    { type: ElementRef }
];
StripeCardExpiry.propDecorators = {
    styleBase: [{ type: Input }],
    styleComplete: [{ type: Input }],
    styleEmpty: [{ type: Input }],
    styleInvalid: [{ type: Input }],
    placeholder: [{ type: Input }],
    disabled: [{ type: Input }]
};

/** Bridge with the Angular's form API */
class StripeCardCvcControl extends StripeControlDirective {
}
StripeCardCvcControl.decorators = [
    { type: Directive, args: [{
                selector: 'wm-stripe-card-cvc[ngModel], wm-stripe-card-cvc[formControl], wm-stripe-card-cvc[formControlName]',
                providers: [
                    { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => StripeCardCvcControl), multi: true },
                    { provide: NG_VALIDATORS, useExisting: forwardRef(() => StripeCardCvcControl), multi: true }
                ]
            },] }
];
/** Stripe Card CVC Element for Angular */
class StripeCardCvc extends StripeElementDirective {
    constructor(elements, ref) {
        super('cardCvc', elements, ref);
        this.ref = ref;
        // Hooks on CardElement specific events
        this.forward(elm => {
            elm.on('change', value => this.valueChange.emit(this._value = value));
            elm.on('escape', () => this.escapeChange.emit());
        });
    }
    // Overrides the disabled getter to effectively return the status
    get disabled() { return !!this.options.disabled; }
    // Ovverrides the disable function forwarding the call to the StripeElement 
    disable(disabled) {
        this.disabled = disabled;
        this.forward(elm => elm.update(this.options));
    }
    // Initializes the element
    ngOnInit() { this.init(this.options); }
    // Updates the element on input changes
    ngOnChanges() { this.forward(elm => elm.update(this.options)); }
    /** Element's custom base style.
     * @see https://stripe.com/docs/js/appendix/style
     * Setting this input value to 'auto' enables the automatic detection of the element's style */
    set styleBase(value) {
        this.style.base = (value === 'auto') ? computeBaseStyle(this.ref.nativeElement) : value;
    }
    /** Element's custom complete style.
     * @see https://stripe.com/docs/js/appendix/style */
    set styleComplete(value) {
        this.style.complete = value;
    }
    /** Element's custom empty style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleEmpty(value) {
        this.style.empty = value;
    }
    /** Element's custom invalid style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleInvalid(value) {
        this.style.invalid = value;
    }
    /** A placeholder text */
    set placeholder(value) {
        this.options.placeholder = value;
    }
    /** Disables the element */
    set disabled(value) {
        this.options.disabled = coerceBooleanProperty(value);
    }
}
StripeCardCvc.decorators = [
    { type: Component, args: [{
                selector: 'wm-stripe-card-cvc',
                template: '',
                providers: [
                    { provide: StripeElementDirective, useExisting: forwardRef(() => StripeCardCvc) }
                ]
            },] }
];
/** @nocollapse */
StripeCardCvc.ctorParameters = () => [
    { type: StripeElementsDirective, decorators: [{ type: Optional }] },
    { type: ElementRef }
];
StripeCardCvc.propDecorators = {
    styleBase: [{ type: Input }],
    styleComplete: [{ type: Input }],
    styleEmpty: [{ type: Input }],
    styleInvalid: [{ type: Input }],
    placeholder: [{ type: Input }],
    disabled: [{ type: Input }]
};

/** Bridge with the Angular's form API */
class StripeCardNumberControl extends StripeControlDirective {
}
StripeCardNumberControl.decorators = [
    { type: Directive, args: [{
                selector: 'wm-stripe-card-number[ngModel], wm-stripe-card-number[formControl], wm-stripe-card-number[formControlName]',
                providers: [
                    { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => StripeCardNumberControl), multi: true },
                    { provide: NG_VALIDATORS, useExisting: forwardRef(() => StripeCardNumberControl), multi: true }
                ]
            },] }
];
/** Stripe CardNumber Element for Angular */
class StripeCardNumber extends StripeElementDirective {
    constructor(elements, ref) {
        super('cardNumber', elements, ref);
        this.ref = ref;
        // Hooks on CardElement specific events
        this.forward(elm => {
            elm.on('change', value => this.valueChange.emit(this._value = value));
            elm.on('escape', () => this.escapeChange.emit());
        });
    }
    // Overrides the disabled getter to effectively return the status
    get disabled() { return !!this.options.disabled; }
    // Ovverrides the disable function forwarding the call to the StripeElement 
    disable(disabled) {
        this.disabled = disabled;
        this.forward(elm => elm.update(this.options));
    }
    // Initializes the element
    ngOnInit() { this.init(this.options); }
    // Updates the element on input changes
    ngOnChanges() { this.forward(elm => elm.update(this.options)); }
    /** Element's custom base style.
     * @see https://stripe.com/docs/js/appendix/style
     * Setting this input value to 'auto' enables the automatic detection of the element's style */
    set styleBase(value) {
        this.style.base = (value === 'auto') ? computeBaseStyle(this.ref.nativeElement) : value;
    }
    /** Element's custom complete style.
     * @see https://stripe.com/docs/js/appendix/style */
    set styleComplete(value) {
        this.style.complete = value;
    }
    /** Element's custom empty style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleEmpty(value) {
        this.style.empty = value;
    }
    /** Element's custom invalid style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleInvalid(value) {
        this.style.invalid = value;
    }
    /** A placeholder text */
    set placeholder(value) {
        this.options.placeholder = value;
    }
    /** Disables the element */
    set disabled(value) {
        this.options.disabled = coerceBooleanProperty(value);
    }
}
StripeCardNumber.decorators = [
    { type: Component, args: [{
                selector: 'wm-stripe-card-number',
                template: '',
                providers: [
                    { provide: StripeElementDirective, useExisting: forwardRef(() => StripeCardNumber) }
                ]
            },] }
];
/** @nocollapse */
StripeCardNumber.ctorParameters = () => [
    { type: StripeElementsDirective, decorators: [{ type: Optional }] },
    { type: ElementRef }
];
StripeCardNumber.propDecorators = {
    styleBase: [{ type: Input }],
    styleComplete: [{ type: Input }],
    styleEmpty: [{ type: Input }],
    styleInvalid: [{ type: Input }],
    placeholder: [{ type: Input }],
    disabled: [{ type: Input }]
};

class StripeCardModule {
}
StripeCardModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [
                    StripeCard, StripeCardControl,
                    StripeCardNumber, StripeCardNumberControl,
                    StripeCardExpiry, StripeCardExpiryControl,
                    StripeCardCvc, StripeCardCvcControl
                ],
                exports: [
                    StripeCard, StripeCardControl,
                    StripeCardNumber, StripeCardNumberControl,
                    StripeCardExpiry, StripeCardExpiryControl,
                    StripeCardCvc, StripeCardCvcControl
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { StripeCard, StripeCardControl, StripeCardCvc, StripeCardCvcControl, StripeCardExpiry, StripeCardExpiryControl, StripeCardModule, StripeCardNumberControl as ɵa, StripeCardNumber as ɵb };
//# sourceMappingURL=wizdm-stripe-elements-card.js.map
