import { StripeControlDirective, StripeElementDirective, computeBaseStyle, StripeElementsDirective } from '@wizdm/stripe/elements';
import { Directive, forwardRef, Component, Optional, ElementRef, Input, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, NG_VALIDATORS } from '@angular/forms';
import { coerceBooleanProperty } from '@angular/cdk/coercion';

/** Bridge with the Angular's form API */
class StripeFpxBankControl extends StripeControlDirective {
}
StripeFpxBankControl.decorators = [
    { type: Directive, args: [{
                selector: 'wm-stripe-fpx-bank[ngModel], wm-stripe-fpx-bank[formControl], wm-stripe-fpx-bank[formControlName]',
                providers: [
                    { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => StripeFpxBankControl), multi: true },
                    { provide: NG_VALIDATORS, useExisting: forwardRef(() => StripeFpxBankControl), multi: true }
                ]
            },] }
];
/** Stripe fpxBank Element
 * @see https://stripe.com/docs/payments/fpx
 */
class StripeFpxBank extends StripeElementDirective {
    constructor(elements, ref) {
        super('fpxBank', elements, ref);
        this.ref = ref;
        // Hooks on CardElement specific events
        this.forward(elm => {
            elm.on('change', value => this.valueChange.emit(this._value = value));
            elm.on('escape', () => this.escapeChange.emit());
        });
    }
    // Overrides the disabled getter to effectively return the status
    get disabled() { return !!this.options.disabled; }
    // Ovverrides the disable function forwarding the call to the StripeElement 
    disable(disabled) {
        this.disabled = disabled;
        this.forward(elm => elm.update(this.options));
    }
    // Initializes the element
    ngOnInit() { this.init(this.options); }
    // Updates the element on input changes
    ngOnChanges() { this.forward(elm => elm.update(this.options)); }
    /** Element's custom base style.
     * @see https://stripe.com/docs/js/appendix/style
     * Setting this input value to 'auto' enables the automatic detection of the element's style */
    set styleBase(value) {
        this.style.base = (value === 'auto') ? computeBaseStyle(this.ref.nativeElement) : value;
    }
    /** Element's custom complete style.
     * @see https://stripe.com/docs/js/appendix/style */
    set styleComplete(value) {
        this.style.complete = value;
    }
    /** Element's custom empty style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleEmpty(value) {
        this.style.empty = value;
    }
    /** Element's custom invalid style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleInvalid(value) {
        this.style.invalid = value;
    }
    /** Account Holder Type */
    set accountHolderType(value) {
        this.options.accountHolderType = value;
    }
    /**
     * A pre-filled value for the Element. Can be one of the banks listed in the
     * @see https://stripe.com/docs/payments/fpx/accept-a-payment#bank-reference
     * @example 'affin_bank'
     */
    set fpxValue(value) {
        this.options.value = value;
    }
    /** Disables the element */
    set disabled(value) {
        this.options.disabled = coerceBooleanProperty(value);
    }
}
StripeFpxBank.decorators = [
    { type: Component, args: [{
                selector: 'wm-stripe-fpx-bank',
                template: '',
                providers: [
                    { provide: StripeElementDirective, useExisting: forwardRef(() => StripeFpxBank) }
                ]
            },] }
];
/** @nocollapse */
StripeFpxBank.ctorParameters = () => [
    { type: StripeElementsDirective, decorators: [{ type: Optional }] },
    { type: ElementRef }
];
StripeFpxBank.propDecorators = {
    styleBase: [{ type: Input }],
    styleComplete: [{ type: Input }],
    styleEmpty: [{ type: Input }],
    styleInvalid: [{ type: Input }],
    accountHolderType: [{ type: Input }],
    fpxValue: [{ type: Input, args: ['value',] }],
    disabled: [{ type: Input }]
};

class StripeFpxBankModule {
}
StripeFpxBankModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [StripeFpxBank, StripeFpxBankControl],
                exports: [StripeFpxBank, StripeFpxBankControl]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { StripeFpxBank, StripeFpxBankControl, StripeFpxBankModule };
//# sourceMappingURL=wizdm-stripe-elements-fpx.js.map
