import { StripeControlDirective, StripeElementDirective, computeBaseStyle, StripeElementsDirective } from '@wizdm/stripe/elements';
import { Directive, forwardRef, Component, Optional, ElementRef, Input, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, NG_VALIDATORS } from '@angular/forms';
import { coerceBooleanProperty } from '@angular/cdk/coercion';

/** Bridge with the Angular's form API */
class StripeIbanControl extends StripeControlDirective {
}
StripeIbanControl.decorators = [
    { type: Directive, args: [{
                selector: 'wm-stripe-iban[ngModel], wm-stripe-iban[formControl], wm-stripe-iban[formControlName]',
                providers: [
                    { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => StripeIbanControl), multi: true },
                    { provide: NG_VALIDATORS, useExisting: forwardRef(() => StripeIbanControl), multi: true }
                ]
            },] }
];
/** Stripe IBAN Element for Angular */
class StripeIban extends StripeElementDirective {
    constructor(elements, ref) {
        super('iban', elements, ref);
        this.ref = ref;
        // Hooks on specific events
        this.forward(elm => {
            elm.on('change', value => this.valueChange.emit(this._value = value));
            elm.on('escape', () => this.escapeChange.emit());
        });
    }
    // Overrides the disabled getter to effectively return the status
    get disabled() { return !!this.options.disabled; }
    // Ovverrides the disable function forwarding the call to the StripeElement 
    disable(disabled) {
        this.disabled = disabled;
        this.forward(elm => elm.update(this.options));
    }
    // Initializes the element
    ngOnInit() { this.init(this.options); }
    // Updates the element on input changes
    ngOnChanges() { this.forward(elm => elm.update(this.options)); }
    /** Element's custom base style.
     * @see https://stripe.com/docs/js/appendix/style
     * Setting this input value to 'auto' enables the automatic detection of the element's style */
    set styleBase(value) {
        this.style.base = (value === 'auto') ? computeBaseStyle(this.ref.nativeElement) : value;
    }
    /** Element's custom complete style.
     * @see https://stripe.com/docs/js/appendix/style */
    set styleComplete(value) {
        this.style.complete = value;
    }
    /** Element's custom empty style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleEmpty(value) {
        this.style.empty = value;
    }
    /** Element's custom invalid style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleInvalid(value) {
        this.style.invalid = value;
    }
    /** Supported countries */
    set supportedCountries(value) {
        this.options.supportedCountries = value;
    }
    /** Placeholder country */
    set placeholderCountry(value) {
        this.options.placeholderCountry = value;
    }
    /** Hides the card icon */
    set hideIcon(value) {
        this.options.hideIcon = coerceBooleanProperty(value);
    }
    /** Selects the icon style */
    set iconStyle(value) {
        this.options.iconStyle = value;
    }
    /** Disables the element */
    set disabled(value) {
        this.options.disabled = coerceBooleanProperty(value);
    }
}
StripeIban.decorators = [
    { type: Component, args: [{
                selector: 'wm-stripe-iban',
                template: '',
                providers: [
                    { provide: StripeElementDirective, useExisting: forwardRef(() => StripeIban) }
                ]
            },] }
];
/** @nocollapse */
StripeIban.ctorParameters = () => [
    { type: StripeElementsDirective, decorators: [{ type: Optional }] },
    { type: ElementRef }
];
StripeIban.propDecorators = {
    styleBase: [{ type: Input }],
    styleComplete: [{ type: Input }],
    styleEmpty: [{ type: Input }],
    styleInvalid: [{ type: Input }],
    supportedCountries: [{ type: Input }],
    placeholderCountry: [{ type: Input }],
    hideIcon: [{ type: Input }],
    iconStyle: [{ type: Input }],
    disabled: [{ type: Input }]
};

class StripeIbanModule {
}
StripeIbanModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [StripeIban, StripeIbanControl],
                exports: [StripeIban, StripeIbanControl]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { StripeIban, StripeIbanControl, StripeIbanModule };
//# sourceMappingURL=wizdm-stripe-elements-iban.js.map
