import { StripeControlDirective, StripeElementDirective, computeBaseStyle, StripeElementsDirective } from '@wizdm/stripe/elements';
import { Directive, forwardRef, Component, Optional, ElementRef, Input, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, NG_VALIDATORS } from '@angular/forms';
import { coerceBooleanProperty } from '@angular/cdk/coercion';

/** Bridge with the Angular's form API */
class StripeIdealBankControl extends StripeControlDirective {
}
StripeIdealBankControl.decorators = [
    { type: Directive, args: [{
                selector: 'wm-stripe-ideal-bank[ngModel], wm-stripe-ideal-bank[formControl], wm-stripe-ideal-bank[formControlName]',
                providers: [
                    { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => StripeIdealBankControl), multi: true },
                    { provide: NG_VALIDATORS, useExisting: forwardRef(() => StripeIdealBankControl), multi: true }
                ]
            },] }
];
/** Stripe Ideal Bank Element for Angular */
class StripeIdealBank extends StripeElementDirective {
    constructor(elements, ref) {
        super('idealBank', elements, ref);
        this.ref = ref;
        // Hooks on specific events
        this.forward(elm => {
            elm.on('change', value => this.valueChange.emit(this._value = value));
            elm.on('escape', () => this.escapeChange.emit());
        });
    }
    // Overrides the disabled getter to effectively return the status
    get disabled() { return !!this.options.disabled; }
    // Ovverrides the disable function forwarding the call to the StripeElement 
    disable(disabled) {
        this.disabled = disabled;
        this.forward(elm => elm.update(this.options));
    }
    // Initializes the element
    ngOnInit() { this.init(this.options); }
    // Updates the element on input changes
    ngOnChanges() { this.forward(elm => elm.update(this.options)); }
    /** Element's custom base style.
     * @see https://stripe.com/docs/js/appendix/style
     * Setting this input value to 'auto' enables the automatic detection of the element's style */
    set styleBase(value) {
        this.style.base = (value === 'auto') ? computeBaseStyle(this.ref.nativeElement) : value;
    }
    /** Element's custom complete style.
     * @see https://stripe.com/docs/js/appendix/style */
    set styleComplete(value) {
        this.style.complete = value;
    }
    /** Element's custom empty style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleEmpty(value) {
        this.style.empty = value;
    }
    /** Element's custom invalid style.
     * @see https://stripe.com/docs/js/appendix/style */
    styleInvalid(value) {
        this.style.invalid = value;
    }
    /**
     * A pre-filled value for the Element. Can be one of the banks listed in the
     * @see https://stripe.com/docs/sources/ideal#optional-specifying-the-customers-bank
     * @example 'abn_amro'
     */
    set idealValue(value) {
        this.options.value = value;
    }
    /** Selects the icon style */
    set iconStyle(value) {
        this.options.iconStyle = value;
    }
    /** Hides the card icon */
    set hideIcon(value) {
        this.options.hideIcon = coerceBooleanProperty(value);
    }
    /** Disables the element */
    set disabled(value) {
        this.options.disabled = coerceBooleanProperty(value);
    }
}
StripeIdealBank.decorators = [
    { type: Component, args: [{
                selector: 'wm-stripe-ideal-bank',
                template: '',
                providers: [
                    { provide: StripeElementDirective, useExisting: forwardRef(() => StripeIdealBank) }
                ]
            },] }
];
/** @nocollapse */
StripeIdealBank.ctorParameters = () => [
    { type: StripeElementsDirective, decorators: [{ type: Optional }] },
    { type: ElementRef }
];
StripeIdealBank.propDecorators = {
    styleBase: [{ type: Input }],
    styleComplete: [{ type: Input }],
    styleEmpty: [{ type: Input }],
    styleInvalid: [{ type: Input }],
    idealValue: [{ type: Input, args: ['value',] }],
    iconStyle: [{ type: Input }],
    hideIcon: [{ type: Input }],
    disabled: [{ type: Input }]
};

class StripeIdealBankModule {
}
StripeIdealBankModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [StripeIdealBank, StripeIdealBankControl],
                exports: [StripeIdealBank, StripeIdealBankControl]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { StripeIdealBank, StripeIdealBankControl, StripeIdealBankModule };
//# sourceMappingURL=wizdm-stripe-elements-ideal.js.map
