import { MatFormFieldControl } from '@angular/material/form-field';
import { StripeElementDirective } from '@wizdm/stripe/elements';
import { Directive, forwardRef, NgModule } from '@angular/core';
import { merge } from 'rxjs';

/**
 * MatFormFieldControl implementation for StripeElement
 */
class StripeMaterialDirective {
    constructor(element) {
        this.element = element;
        this.stateChanges = merge(element.readyChange, element.focusChange, element.blurChange, element.valueChange);
    }
    /** The value of the control. */
    get value() { return this.element.value || null; }
    ;
    /** Whether the control is focused. */
    get focused() { return this.element.focused; }
    /** Whether the control is empty. */
    get empty() { return !this.element.empty; }
    /** Whether the control is disabled. */
    get disabled() { return this.element.disabled; }
    /** Whether the `MatFormField` label should try to float. */
    get shouldLabelFloat() { return true; }
    ;
    /** Whether the control is in an error state. */
    get errorState() {
        const value = this.element.value;
        return !!value && !!value.error;
    }
    ;
    /** Sets the list of element IDs that currently describe this control. */
    setDescribedByIds(ids) { }
    /** Handles a click on the control's container. */
    onContainerClick(event) {
        this.element.focus();
    }
    ;
}
StripeMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: '[matStripe]',
                host: { 'class': 'wm-stripe-material' },
                providers: [
                    { provide: MatFormFieldControl, useExisting: forwardRef(() => StripeMaterialDirective) }
                ]
            },] }
];
/** @nocollapse */
StripeMaterialDirective.ctorParameters = () => [
    { type: StripeElementDirective }
];

class StripeMaterialModule {
}
StripeMaterialModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [StripeMaterialDirective],
                exports: [StripeMaterialDirective]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { StripeMaterialDirective, StripeMaterialModule };
//# sourceMappingURL=wizdm-stripe-material.js.map
