import type { Stripe, StripeConstructor, StripeConstructorOptions } from '@stripe/stripe-js';
import { Observable } from 'rxjs';
/** StripeCaller class implements an observable-based proxy to call the Stripe.js SDK */
export declare class StripeCaller {
    /** The optional stripe account to connect to @see [Connect](https://stripe.com/docs/connect) */
    private account$;
    /**
     * For usage with [Connect](https://stripe.com/docs/connect) only.
     * Specifying a connected account ID (e.g., `acct_24BFMpJ1svR5A89k`) allows you to perform actions on behalf of that account.
     */
    connect(stripeAccount: string): void;
    /** The active Stripe instance observable */
    readonly stripe$: Observable<Stripe>;
    constructor(stripejs: Promise<StripeConstructor>, publicKey: string, options: StripeConstructorOptions);
    /** Invokes the requested Stripe funciton */
    protected callStripe(signature: string, args: any): Promise<any>;
}
